CalendarCoordinator | django_cradmin API Document

    import {CalendarCoordinator} from 'django_cradmin/scripts/django_cradmin/utilities/Calendar.js'

public class | source

# CalendarCoordinator

Coordinates the common calendar data no matter what kind of view we present.

## Constructor Summary

Public Constructor
public | constructor(objectPattern: {"selectedMomentObject": *, "minimumDatetime": *, "maximumDatetime": *, "nowMomentObject": *}) |

## Member Summary

Public Members
public | maximumDatetime: * |
public | minimumDatetime: * |
public | nowMomentObject: * |
public | selectedMomentObject: * |
public | shownMomentObject: * |

## Method Summary

Public Methods
public | clearSelectedMomentObject(): * |
public | momentObjectIsAllowed(momentObject: *, ignoreTime: boolean): * |
public | nowIsValidValue(): * |
public | selectShownValue(): * |
public | setToNow(): * |
public | shownDateIsToday(): * |
public | shownDateIsTodayAndNowIsValid(): * |
public | todayIsValidValue(): * |

## Public Constructors

### public constructor(objectPattern: {"selectedMomentObject": *, "minimumDatetime": *, "maximumDatetime": *, "nowMomentObject": *}) source

#### Params:

Name | Type | Attribute | Description
objectPattern | {"selectedMomentObject": *, "minimumDatetime": *, "maximumDatetime": *, "nowMomentObject": *} | default: {"selectedMomentObject":null,"minimumDatetime":null,"maximumDatetime":null,"nowMomentObject":null} |

## Public Members

### public maximumDatetime: * source

### public minimumDatetime: * source

### public nowMomentObject: * source

### public selectedMomentObject: * source

### public shownMomentObject: * source

## Public Methods

### public clearSelectedMomentObject(): * source

#### Return:

*

### public momentObjectIsAllowed(momentObject: *, ignoreTime: boolean): * source

#### Params:

Name | Type | Attribute | Description
momentObject | * |  |
ignoreTime | boolean | optional default: true |

#### Return:

*

### public nowIsValidValue(): * source

#### Return:

*

### public selectShownValue(): * source

#### Return:

*

### public setToNow(): * source

#### Return:

*

### public shownDateIsToday(): * source

#### Return:

*

### public shownDateIsTodayAndNowIsValid(): * source

#### Return:

*

### public todayIsValidValue(): * source

#### Return:

*